==> jc-1.4.0.tar.gz: javax/swing/text/Position__24Bias.h <==
// public class javax.swing.text.Position$Bias

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fa42467a9d08efa6 javax_swing_text_Position__24Bias

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_Position__24Bias_H_
#define _JC_javax_swing_text_Position__24Bias_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_Position__24Bias$sub_refs	_jc_javax_swing_text_Position__24Bias$sub_refs;
typedef struct _jc_javax_swing_text_Position__24Bias$sub_nonrefs	_jc_javax_swing_text_Position__24Bias$sub_nonrefs;
typedef struct _jc_javax_swing_text_Position__24Bias$refs	_jc_javax_swing_text_Position__24Bias$refs;
typedef struct _jc_javax_swing_text_Position__24Bias$nonrefs	_jc_javax_swing_text_Position__24Bias$nonrefs;
typedef struct _jc_javax_swing_text_Position__24Bias$object	_jc_javax_swing_text_Position__24Bias$object;

typedef struct _jc_javax_swing_text_Position__24Bias$fields_struct	_jc_javax_swing_text_Position__24Bias$fields_struct;
typedef const struct _jc_javax_swing_text_Position__24Bias$vmethods	_jc_javax_swing_text_Position__24Bias$vmethods;
typedef const struct _jc_javax_swing_text_Position__24Bias$vtable	_jc_javax_swing_text_Position__24Bias$vtable;
typedef const struct _jc_javax_swing_text_Position__24Bias$vtype	_jc_javax_swing_text_Position__24Bias$vtype;

// Class fields structure
struct _jc_javax_swing_text_Position__24Bias$fields_struct {
	struct _jc_javax_swing_text_Position__24Bias$object	*Backward;
	struct _jc_javax_swing_text_Position__24Bias$object	*Forward;
};
extern _jc_javax_swing_text_Position__24Bias$fields_struct _jc_javax_swing_text_Position__24Bias$class_fields;

// Constructors
extern void _jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_Position__24Bias$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *);
};

// Vtable
struct _jc_javax_swing_text_Position__24Bias$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_Position__24Bias$vmethods	javax_swing_text_Position__24Bias;
};

// Vtype
struct _jc_javax_swing_text_Position__24Bias$vtype {
	_jc_type			type;
	_jc_javax_swing_text_Position__24Bias$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_Position__24Bias$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_Position__24Bias$refs {
    _jc_javax_swing_text_Position__24Bias$sub_refs	javax_swing_text_Position__24Bias;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_Position__24Bias$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_Position__24Bias$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_Position__24Bias$sub_nonrefs	javax_swing_text_Position__24Bias;
};

// Object instance structure
struct _jc_javax_swing_text_Position__24Bias$object {
	_jc_javax_swing_text_Position__24Bias$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_Position__24Bias$vtype	*vtype;
	_jc_javax_swing_text_Position__24Bias$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_Position__24Bias$vtype _jc_javax_swing_text_Position__24Bias$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_Position__24Bias, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_Position__24Bias$class_object;

#endif	/* _JC_javax_swing_text_Position__24Bias_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/Position__24Bias.h <==
// public class javax.swing.text.Position$Bias

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fa42467a9d08efa6 javax_swing_text_Position__24Bias

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_Position__24Bias_H_
#define _JC_javax_swing_text_Position__24Bias_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_Position__24Bias$sub_refs	_jc_javax_swing_text_Position__24Bias$sub_refs;
typedef struct _jc_javax_swing_text_Position__24Bias$sub_nonrefs	_jc_javax_swing_text_Position__24Bias$sub_nonrefs;
typedef struct _jc_javax_swing_text_Position__24Bias$refs	_jc_javax_swing_text_Position__24Bias$refs;
typedef struct _jc_javax_swing_text_Position__24Bias$nonrefs	_jc_javax_swing_text_Position__24Bias$nonrefs;
typedef struct _jc_javax_swing_text_Position__24Bias$object	_jc_javax_swing_text_Position__24Bias$object;

typedef struct _jc_javax_swing_text_Position__24Bias$fields_struct	_jc_javax_swing_text_Position__24Bias$fields_struct;
typedef const struct _jc_javax_swing_text_Position__24Bias$vmethods	_jc_javax_swing_text_Position__24Bias$vmethods;
typedef const struct _jc_javax_swing_text_Position__24Bias$vtable	_jc_javax_swing_text_Position__24Bias$vtable;
typedef const struct _jc_javax_swing_text_Position__24Bias$vtype	_jc_javax_swing_text_Position__24Bias$vtype;

// Class fields structure
struct _jc_javax_swing_text_Position__24Bias$fields_struct {
	struct _jc_javax_swing_text_Position__24Bias$object	*Backward;
	struct _jc_javax_swing_text_Position__24Bias$object	*Forward;
};
extern _jc_javax_swing_text_Position__24Bias$fields_struct _jc_javax_swing_text_Position__24Bias$class_fields;

// Constructors
extern void _jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_Position__24Bias$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_Position__24Bias$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_Position__24Bias$vmethods	javax_swing_text_Position__24Bias;
};

// Vtype
struct _jc_javax_swing_text_Position__24Bias$vtype {
	_jc_type			type;
	_jc_javax_swing_text_Position__24Bias$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_Position__24Bias$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_Position__24Bias$refs {
    _jc_javax_swing_text_Position__24Bias$sub_refs	javax_swing_text_Position__24Bias;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_Position__24Bias$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_Position__24Bias$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_Position__24Bias$sub_nonrefs	javax_swing_text_Position__24Bias;
};

// Object instance structure
struct _jc_javax_swing_text_Position__24Bias$object {
	_jc_javax_swing_text_Position__24Bias$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_Position__24Bias$vtype	*vtype;
	_jc_javax_swing_text_Position__24Bias$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_Position__24Bias$vtype _jc_javax_swing_text_Position__24Bias$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_Position__24Bias, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_Position__24Bias$class_object;

#endif	/* _JC_javax_swing_text_Position__24Bias_H_ */
